UnderflowError class

Underflow errors happen when the socket feeding a buffer is finished while there are still blocked readers. Each reader will complete with this error.

Inheritance

Constructors

UnderflowError([String? message])
The message describes the underflow.

Properties

hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stackTrace → StackTrace?
The stack trace at the point where this error was first thrown.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited