ListMultimap<K, V>.fromIterable constructor
ListMultimap<K, V>.fromIterable (
- Iterable iterable, {
- K key(
- dynamic
- V value(
- dynamic
Constructs a new list-backed multimap.
For each element e of iterable, adds an association from key(e) to
value(e). key and value each default to the identity function.
Implementation
ListMultimap.fromIterable(super.iterable, {super.key, super.value})
: super.fromIterable();