TreeIterator<V> class
This iterator either starts at the beginning or end (see TreeSet.iterator and TreeSet.reverseIterator) or from an anchor point in the set (see TreeSet.fromIterator). When using fromIterator, the initial anchor point is included in the first movement (either moveNext or movePrevious) but can optionally be excluded in the constructor.
- Implemented types
-
- Iterator<
V>
- Iterator<
- Available extensions
Properties
- current → V
-
The current element.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- inclusive → bool
-
final
- reversed → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
toJSIterator
→ JSIterator<
T> -
Available on Iterator<
A JSIterator wrapper that proxies to the Dart iterator API.T> , provided by the IteratorToJSIterator extensionno setter -
tree
→ AvlTreeSet<
V> -
final
Methods
-
moveNext(
) → bool -
Advances the iterator to the next element of the iteration.
override
-
movePrevious(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited