TreeSet<V> class abstract

A Set of items stored in a binary tree according to comparator. Supports bidirectional iteration.

Inheritance
Implemented types
Implementers
Available extensions

Constructors

TreeSet({Comparator<V> comparator = _defaultCompare})
Create a new TreeSet with an ordering defined by comparator or the default (a, b) => a.compareTo(b).
factory

Properties

comparator → Comparator<V>
final
first → V
The first element.
no setterinherited
firstOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The first element of this iterator, or null if the iterable is empty.
no setter
hashCode → int
The hash code for this object.
no setterinherited
indexed → Iterable<(int, T)>

Available on Iterable<T>, provided by the IterableExtensions extension

Pairs of elements of the indices and elements of this iterable.
no setter
isEmpty → bool
Whether this collection has no elements.
no setteroverride
isNotEmpty → bool
Whether this collection has at least one element.
no setteroverride
iterator → TreeIterator<V>
Returns a TreeIterator that iterates over this tree.
no setteroverride
last → V
The last element.
no setterinherited
lastOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The last element of this iterable, or null if the iterable is empty.
no setter
length → int
The number of elements in this Iterable.
no setteroverride
nonNulls → Iterable<T>

Available on Iterable<T?>, provided by the NullableIterableExtensions extension

The non-null elements of this iterable.
no setter
reverseIterator → TreeIterator<V>
Returns a TreeIterator that iterates over this tree, in reverse.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
single → V
Checks that this iterable has only one element, and returns that element.
no setterinherited
singleOrNull → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The single element of this iterator, or null.
no setter
toJSIterable → JSIterable<T>

Available on Iterable<T>, provided by the IterableToJSIterable extension

A JSIterable wrapper that proxies to the Dart iterable API.
no setter
wait → Future<List<T>>

Available on Iterable<Future<T>>, provided by the FutureIterable extension

Waits for futures in parallel.
no setter

Methods

add(V value) → bool
Adds value to the set.
inherited
addAll(Iterable<V> elements) → void
Adds all elements to this set.
inherited
any(bool test(V value)) → bool
Checks whether any element of this iterable satisfies test.
inherited
asNameMap() → Map<String, T>

Available on Iterable<T>, provided by the EnumByName extension

Creates a map from the names of enum values to the values.
byName(String name) → T

Available on Iterable<T>, provided by the EnumByName extension

Finds the enum value in this list with name name.
cast<T>() → Set<T>
A view of this iterable as an iterable of R instances.
override
clear() → void
Removes all elements from the set.
inherited
contains(Object? element) → bool
Whether the collection contains an element equal to element.
inherited
containsAll(Iterable<Object?> other) → bool
Whether this set contains all the elements of other.
inherited
difference(Set<Object?> other) → Set<V>
Creates a new set with the elements of this that are not in other.
inherited
elementAt(int index) → V
Returns the indexth element.
inherited
elementAtOrNull(int index) → T?

Available on Iterable<T>, provided by the IterableExtensions extension

The element at position index of this iterable, or null.
every(bool test(V value)) → bool
Checks whether every element of this iterable satisfies test.
inherited
expand<T>(Iterable<T> toElements(V element)) → Iterable<T>
Expands each element of this Iterable into zero or more elements.
inherited
firstWhere(bool test(V value), {V orElse()?}) → V
The first element that satisfies the given predicate test.
inherited
fold<T>(T initialValue, T combine(T previousValue, V element)) → T
Reduces a collection to a single value by iteratively combining each element of the collection with an existing value
inherited
followedBy(Iterable<V> other) → Iterable<V>
Creates the lazy concatenation of this iterable and other.
inherited
forEach(void action(V element)) → void
Invokes action on each element of this iterable in iteration order.
inherited
fromIterator(V anchor, {bool reversed = false, bool inclusive = true}) → TreeIterator<V>
Returns a TreeIterator that starts at anchor. By default, the iterator includes the anchor with the first movement; set inclusive to false if you want to exclude the anchor. Set reversed to true to change the direction of of moveNext and movePrevious.
intersection(Set<Object?> other) → Set<V>
Creates a new set which is the intersection between this set and other.
inherited
join([String separator = ""]) → String
Converts each element to a String and concatenates the strings.
inherited
lastWhere(bool test(V value), {V orElse()?}) → V
The last element that satisfies the given predicate test.
inherited
lookup(Object? object) → V?
If an object equal to object is in the set, return it.
inherited
map<T>(T toElement(V e)) → Iterable<T>
The current elements of this iterable modified by toElement.
inherited
nearest(V object, {TreeSearch nearestOption = TreeSearch.NEAREST}) → V
Search the tree for the matching object or the nearestOption if missing. See TreeSearch.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(V combine(V value, V element)) → V
Reduces a collection to a single value by iteratively combining elements of the collection using the provided function.
inherited
remove(Object? value) → bool
Removes value from the set.
inherited
removeAll(Iterable<Object?> elements) → void
Removes each element of elements from this set.
inherited
removeWhere(bool test(V value)) → void
Removes all elements of this set that satisfy test.
inherited
retainAll(Iterable<Object?> elements) → void
Removes all elements of this set that are not elements in elements.
inherited
retainWhere(bool test(V value)) → void
Removes all elements of this set that fail to satisfy test.
inherited
singleWhere(bool test(V value), {V orElse()?}) → V
The single element that satisfies test.
inherited
skip(int count) → Iterable<V>
Creates an Iterable that provides all but the first count elements.
inherited
skipWhile(bool test(V value)) → Iterable<V>
Creates an Iterable that skips leading elements while test is satisfied.
inherited
take(int count) → Iterable<V>
Creates a lazy iterable of the count first elements of this iterable.
inherited
takeWhile(bool test(V value)) → Iterable<V>
Creates a lazy iterable of the leading elements satisfying test.
inherited
toList({bool growable = true}) → List<V>
Creates a List containing the elements of this Iterable.
inherited
toSet() → Set<V>
Creates a Set containing the same elements as this iterable.
inherited
toString() → String
Returns a string representation of (some of) the elements of this.
inherited
union(Set<V> other) → Set<V>
Creates a new set which contains all the elements of this set and other.
inherited
where(bool test(V value)) → Iterable<V>
Creates a new lazy Iterable with all elements that satisfy the predicate test.
inherited
whereType<T>() → Iterable<T>
Creates a new lazy Iterable with all elements that have type T.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited