Glob class

A Pattern that matches against filesystem path-like strings with wildcards.

The pattern matches strings as follows:

  • The whole string must match, not a substring
  • Any non wildcard is matched as a literal
  • '*' matches one or more characters except '/'
  • '?' matches exactly one character except '/'
  • '**' matches one or more characters including '/'
Implemented types

Constructors

Glob(String pattern)

Properties

hashCode → int
The hash code for this object.
no setteroverride
pattern → String
final
regex → RegExp
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

allMatches(String str, [int start = 0]) → Iterable<Match>
Matches this pattern against the string repeatedly.
override
hasMatch(String str) → bool
matchAsPrefix(String string, [int start = 0]) → Match?
Matches this pattern against the start of string.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override